translate.convert.json2po.json2po

Package translate :: Package convert :: Module json2po :: Class json2po |
[hide private]
[frames] | no frames]

# Class json2po

source code

Convert a JSON file to a PO file

Instance Methods | [hide private]
convert_store(self, input_store, duplicatestyle="msgctxt") Converts a JSON file to a PO file | source code
merge_store(self, template_store, input_store, blankmsgstr=False, duplicatestyle="msgctxt") Converts two JSON files to a PO file | source code
convert_unit(self, input_unit, commenttype) Converts a JSON unit to a PO unit | source code

Method Details | [hide private]

### convert_unit(self, input_unit, commenttype) | source code
Converts a JSON unit to a PO unit Returns: None if empty or not for translation